@@ -7,7 +7,7 @@ from ..examples import make_example_dataset
 
 
 class TestExampleSimulatedDataset:
-    def setup(self):
+    def setup_method(self):
         self.dataset = make_example_dataset(data='simulated')
 
     def test_source_table(self):
