@@ -32,6 +32,7 @@ class CompoundPixelRegion(PixelRegion):
     """
 
     _params = ('region1', 'region2', 'operator')
+    _mpl_artist = 'Patch'
     region1 = RegionType('region1', PixelRegion)
     region2 = RegionType('region2', PixelRegion)
 
@@ -44,11 +45,11 @@ class CompoundPixelRegion(PixelRegion):
         if meta is None:
             self.meta = region1.meta
         else:
-            self.meta = RegionMeta()
+            self.meta = meta
         if visual is None:
             self.visual = region1.visual
         else:
-            self.visual = RegionVisual()
+            self.visual = visual
         self._operator = operator
 
     @property
@@ -91,8 +92,8 @@ class CompoundPixelRegion(PixelRegion):
         skyreg1 = self.region1.to_sky(wcs=wcs)
         skyreg2 = self.region2.to_sky(wcs=wcs)
         return CompoundSkyRegion(region1=skyreg1, operator=self.operator,
-                                 region2=skyreg2, meta=self.meta,
-                                 visual=self.visual)
+                                 region2=skyreg2, meta=self.meta.copy(),
+                                 visual=self.visual.copy())
 
     @staticmethod
     def _make_annulus_path(patch_inner, patch_outer):
@@ -147,13 +148,20 @@ class CompoundPixelRegion(PixelRegion):
 
             import matplotlib.patches as mpatches
 
+            # set mpl_kwargs before as_artist is called on region1 and
+            # region2
+            mpl_kwargs = self.visual.define_mpl_kwargs(self._mpl_artist)
+            mpl_kwargs.update(kwargs)
+
             patch_inner = self.region1.as_artist(origin=origin)
             patch_outer = self.region2.as_artist(origin=origin)
             path = self._make_annulus_path(patch_inner, patch_outer)
-            patch = mpatches.PathPatch(path, **kwargs)
+
+            patch = mpatches.PathPatch(path, **mpl_kwargs)
             return patch
         else:
-            raise NotImplementedError
+            raise ValueError('unable to convert region to matplotlib '
+                             f'artist: {self}')
 
     @property
     def bounding_box(self):
@@ -167,7 +175,7 @@ class CompoundPixelRegion(PixelRegion):
         """
         Rotate the region.
 
-        Postive ``angle`` corresponds to counter-clockwise rotation.
+        Positive ``angle`` corresponds to counter-clockwise rotation.
 
         Parameters
         ----------
@@ -242,8 +250,8 @@ class CompoundSkyRegion(SkyRegion):
         pixreg1 = self.region1.to_pixel(wcs=wcs)
         pixreg2 = self.region2.to_pixel(wcs=wcs)
         return CompoundPixelRegion(region1=pixreg1, operator=self.operator,
-                                   region2=pixreg2, meta=self.meta,
-                                   visual=self.visual)
+                                   region2=pixreg2, meta=self.meta.copy(),
+                                   visual=self.visual.copy())
 
     def as_artist(self, ax, **kwargs):
         raise NotImplementedError
