@@ -3,6 +3,8 @@ import abc
 import copy
 import operator
 
+import numpy as np
+
 from .metadata import RegionMeta, RegionVisual
 from .pixcoord import PixCoord
 from .registry import RegionsRegistry
@@ -35,7 +37,12 @@ class Region(abc.ABC):
         cls_info = []
         if self._params is not None:
             for param in self._params:
-                cls_info.append(f'{param}={getattr(self, param)}')
+                if param == 'text':
+                    # place quotes around text value
+                    keyval = f'{param}={getattr(self, param)!r}'
+                else:
+                    keyval = f'{param}={getattr(self, param)}'
+                cls_info.append(keyval)
         cls_info = ', '.join(cls_info)
         return f'<{prefix}({cls_info})>'
 
@@ -43,9 +50,56 @@ class Region(abc.ABC):
         cls_info = [('Region', self.__class__.__name__)]
         if self._params is not None:
             for param in self._params:
-                cls_info.append((param, getattr(self, param)))
+                if param == 'text':
+                    # place quotes around text value
+                    keyval = (param, repr(getattr(self, param)))
+                else:
+                    keyval = (param, getattr(self, param))
+                cls_info.append(keyval)
+
         return '\n'.join([f'{key}: {val}' for key, val in cls_info])
 
+    def __eq__(self, other):
+        """
+        Equality operator for Region.
+
+        All Region properties are compared for strict equality except
+        for Quantity parameters, which allow for different units if they
+        are directly convertible.
+        """
+        if not isinstance(other, self.__class__):
+            return False
+
+        meta_params = ['meta', 'visual']
+        self_params = list(self._params) + meta_params
+        other_params = list(other._params) + meta_params
+
+        # check that both have identical parameters
+        if self_params != other_params:
+            return False
+
+        # now check the parameter values
+        # Note that Quantity comparisons allow for different units
+        # if they directly convertible (e.g., 1. * u.deg == 60. * u.arcmin)
+        try:
+            for param in self_params:
+                # np.any is used for SkyCoord array comparisons
+                if np.any(getattr(self, param) != getattr(other, param)):
+                    return False
+        except TypeError:
+            # TypeError is raised from SkyCoord comparison when they do
+            # not have equivalent frames. Here return False instead of
+            # the TypeError.
+            return False
+
+        return True
+
+    def __ne__(self, other):
+        """
+        Inequality operator for Region.
+        """
+        return not (self == other)
+
     @abc.abstractmethod
     def intersection(self, other):
         """
@@ -226,7 +280,7 @@ class PixelRegion(Region):
     @abc.abstractmethod
     def area(self):
         """
-        The area of the region.
+        The exact analytical area of the region shape.
         """
         raise NotImplementedError
 
@@ -318,43 +372,6 @@ class PixelRegion(Region):
         """
         raise NotImplementedError
 
-    def _define_mpl_kwargs(self, artist='Patch'):
-        """
-        Define a dictionary of matplotlib keywords for the input
-        ``artist`` from the region's ``visual`` properties.
-
-        Unset ``visual`` properties are set to default values based on
-        the DS9 convention.
-        """
-        if artist not in ('Patch', 'Line2D', 'Text'):
-            raise ValueError(f'artist "{artist}" is not supported')
-
-        kwargs = {}
-        kwargs['color'] = self.visual.get('color', 'green')
-        kwargs['label'] = self.meta.get('label', '')
-
-        if artist == 'Text':
-            kwargs['family'] = self.visual.get('font', 'helvetica')
-            kwargs['style'] = self.visual.get('fontsyle', 'normal')
-            kwargs['weight'] = self.visual.get('fontweight', 'roman')
-            kwargs['size'] = self.visual.get('fontsize', '12')
-            kwargs['rotation'] = self.visual.get('textangle', '0')
-        else:
-            kwargs['linewidth'] = self.visual.get('linewidth', 1)
-            kwargs['linestyle'] = self.visual.get('linstyle', 'solid')
-
-            if artist == 'Line2D':
-                kwargs['marker'] = self.visual.get('symbol', 'o')
-                kwargs['markersize'] = self.visual.get('symsize', 11)
-                kwargs['markeredgecolor'] = kwargs['color']
-                kwargs['markeredgewidth'] = self.visual.get('width', 1)
-
-            if artist == 'Patch':
-                kwargs['edgecolor'] = kwargs.pop('color')
-                kwargs['fill'] = self.visual.get('fill', False)
-
-        return kwargs
-
     def plot(self, origin=(0, 0), ax=None, **kwargs):
         """
         Plot the region on a matplotlib `~matplotlib.axes.Axes`
@@ -376,8 +393,10 @@ class PixelRegion(Region):
 
         Returns
         -------
-        ax : `~matplotlib.axes.Axes`
-            The axes on which the patch was added.
+        artist : `matplotlib.artist.Artist`
+            The matplotlib artist (typically a `~matplotlib.patches.Patch`
+            object) for the plotted region. The artist can be used, for
+            example, when adding a plot legend.
         """
         import matplotlib.pyplot as plt
 
@@ -387,7 +406,7 @@ class PixelRegion(Region):
         artist = self.as_artist(origin=origin, **kwargs)
         ax.add_artist(artist)
 
-        return ax
+        return artist
 
 
 class SkyRegion(Region):
