@@ -438,9 +438,9 @@ class _Shape:
         viz_keywords = ['color', 'dash', 'dashlist', 'width', 'font',
                         'symsize', 'symbol', 'symsize', 'fontsize',
                         'fontstyle', 'usetex', 'labelpos', 'labeloff',
-                        'linewidth', 'linestyle', 'point', 'textangle',
-                        'fontweight', 'symthick', 'default_style', 'fill',
-                        'textrotate']
+                        'labelcolor', 'linewidth', 'linestyle', 'point',
+                        'textangle', 'fontweight', 'symthick', 'default_style',
+                        'fill', 'textrotate', 'fontstyle']
 
         if isinstance(coords[0], SkyCoord):
             reg = self.shape_to_sky_region[self.region_type](*coords)
