@@ -7,10 +7,11 @@ import abc
 import operator
 
 import astropy.units as u
-from astropy.wcs.utils import pixel_to_skycoord
 
-from ..core.attributes import (ScalarPix, ScalarLength, QuantityLength,
-                               ScalarSky)
+from ..core.attributes import (ScalarPixCoord, PositiveScalar,
+                               PositiveScalarAngle, ScalarAngle,
+                               ScalarSkyCoord, RegionMetaDescr,
+                               RegionVisualDescr)
 from ..core.compound import CompoundPixelRegion
 from ..core.core import PixelRegion, SkyRegion
 from ..core.metadata import RegionMeta, RegionVisual
@@ -51,14 +52,14 @@ class AnnulusPixelRegion(PixelRegion, abc.ABC):
     def as_artist(self, origin=(0, 0), **kwargs):
         return self._compound_region.as_artist(origin, **kwargs)
 
-    def to_mask(self, mode="center", subpixels=5):
+    def to_mask(self, mode='center', subpixels=5):
         return self._compound_region.to_mask(mode, subpixels)
 
     def rotate(self, center, angle):
         """
         Rotate the region.
 
-        Postive ``angle`` corresponds to counter-clockwise rotation.
+        Positive ``angle`` corresponds to counter-clockwise rotation.
 
         Parameters
         ----------
@@ -88,13 +89,13 @@ class CircleAnnulusPixelRegion(AnnulusPixelRegion):
     center : `~regions.PixCoord`
         The position of the center of the annulus.
     inner_radius : float
-        The inner radius of the annulus.
+        The inner radius of the annulus in pixels.
     outer_radius : float
-        The outer radius of the annulus.
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+        The outer radius of the annulus in pixels.
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
 
     Examples
@@ -105,28 +106,27 @@ class CircleAnnulusPixelRegion(AnnulusPixelRegion):
         from regions import PixCoord, CircleAnnulusPixelRegion
         import matplotlib.pyplot as plt
 
-        x, y = 6, 6
-        inner_radius = 5.5
-        outer_radius = 8
         fig, ax = plt.subplots(1, 1)
 
-        center = PixCoord(x=x, y=y)
-        reg = CircleAnnulusPixelRegion(center=center,
-                                       inner_radius=inner_radius,
-                                       outer_radius=outer_radius)
-        patch = reg.as_artist(facecolor='none', edgecolor='red', lw=2)
-        ax.add_patch(patch)
+        reg = CircleAnnulusPixelRegion(PixCoord(x=6, y=6),
+                                       inner_radius=5.5,
+                                       outer_radius=8.0)
+        patch = reg.plot(ax=ax, facecolor='none', edgecolor='red', lw=2,
+                         label='Circle Annulus')
 
-        plt.xlim(-5, 20)
-        plt.ylim(-5, 20)
+        ax.legend(handles=(patch,), loc='upper center')
+        ax.set_xlim(-5, 20)
+        ax.set_ylim(-5, 20)
         ax.set_aspect('equal')
     """
 
     _component_class = CirclePixelRegion
     _params = ('center', 'inner_radius', 'outer_radius')
-    center = ScalarPix('center')
-    inner_radius = ScalarLength('inner_radius')
-    outer_radius = ScalarLength('outer_radius')
+    center = ScalarPixCoord('The center pixel position as a |PixCoord|.')
+    inner_radius = PositiveScalar('The inner radius in pixels as a float.')
+    outer_radius = PositiveScalar('The outer radius in pixels as a float.')
+    meta = RegionMetaDescr('The meta attributes as a |RegionMeta|')
+    visual = RegionVisualDescr('The visual attributes as a |RegionVisual|.')
 
     def __init__(self, center, inner_radius, outer_radius, meta=None,
                  visual=None):
@@ -136,6 +136,9 @@ class CircleAnnulusPixelRegion(AnnulusPixelRegion):
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
 
+        if inner_radius >= outer_radius:
+            raise ValueError('outer_radius must be greater than inner_radius')
+
     @property
     def _inner_region(self):
         return self._component_class(self.center, self.inner_radius,
@@ -147,12 +150,12 @@ class CircleAnnulusPixelRegion(AnnulusPixelRegion):
                                      self.meta, self.visual)
 
     def to_sky(self, wcs):
-        center = pixel_to_skycoord(self.center.x, self.center.y, wcs)
+        center = wcs.pixel_to_world(self.center.x, self.center.y)
         _, pixscale, _ = pixel_scale_angle_at_skycoord(center, wcs)
         inner_radius = self.inner_radius * u.pix * pixscale
         outer_radius = self.outer_radius * u.pix * pixscale
         return CircleAnnulusSkyRegion(center, inner_radius, outer_radius,
-                                      self.meta, self.visual)
+                                      self.meta.copy(), self.visual.copy())
 
 
 class CircleAnnulusSkyRegion(SkyRegion):
@@ -167,17 +170,21 @@ class CircleAnnulusSkyRegion(SkyRegion):
         The inner radius of the annulus in angular units.
     outer_radius : `~astropy.units.Quantity`
         The outer radius of the annulus in angular units.
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
     """
 
     _params = ('center', 'inner_radius', 'outer_radius')
-    center = ScalarSky('center')
-    inner_radius = QuantityLength('inner_radius')
-    outer_radius = QuantityLength('outer_radius')
+    center = ScalarSkyCoord('The center position as a |SkyCoord|.')
+    inner_radius = PositiveScalarAngle('The inner radius as a |Quantity| '
+                                       'angle.')
+    outer_radius = PositiveScalarAngle('The outer radius as a |Quantity| '
+                                       'angle.')
+    meta = RegionMetaDescr('The meta attributes as a |RegionMeta|')
+    visual = RegionVisualDescr('The visual attributes as a |RegionVisual|.')
 
     def __init__(self, center, inner_radius, outer_radius, meta=None,
                  visual=None):
@@ -187,12 +194,16 @@ class CircleAnnulusSkyRegion(SkyRegion):
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
 
+        if inner_radius >= outer_radius:
+            raise ValueError('outer_radius must be greater than inner_radius')
+
     def to_pixel(self, wcs):
         center, pixscale, _ = pixel_scale_angle_at_skycoord(self.center, wcs)
         inner_radius = (self.inner_radius / pixscale).to(u.pix).value
         outer_radius = (self.outer_radius / pixscale).to(u.pix).value
         return CircleAnnulusPixelRegion(center, inner_radius, outer_radius,
-                                        self.meta, self.visual)
+                                        meta=self.meta.copy(),
+                                        visual=self.visual.copy())
 
 
 class AsymmetricAnnulusPixelRegion(AnnulusPixelRegion):
@@ -209,10 +220,10 @@ class AsymmetricAnnulusPixelRegion(AnnulusPixelRegion):
         The position of the center of the annulus.
     inner_width : float
         The inner width of the annulus (before rotation) in pixels.
-    inner_height : float
-        The inner height of the annulus (before rotation) in pixels.
     outer_width : float
         The outer width of the annulus (before rotation) in pixels.
+    inner_height : float
+        The inner height of the annulus (before rotation) in pixels.
     outer_height : float
         The outer height of the annulus (before rotation) in pixels.
     angle : `~astropy.units.Quantity`, optional
@@ -221,14 +232,21 @@ class AsymmetricAnnulusPixelRegion(AnnulusPixelRegion):
         axis.
     """
 
-    _params = ('center', 'inner_width', 'inner_height', 'outer_width',
+    _params = ('center', 'inner_width', 'outer_width', 'inner_height',
                'outer_height', 'angle')
-    center = ScalarPix('center')
-    inner_width = ScalarLength('inner_width')
-    outer_width = ScalarLength('outer_width')
-    inner_height = ScalarLength('inner_height')
-    outer_height = ScalarLength('outer_height')
-    angle = QuantityLength('angle')
+    center = ScalarPixCoord('The center pixel position as a |PixCoord|.')
+    inner_width = PositiveScalar('The inner width (before rotation) in '
+                                 'pixels as a float.')
+    outer_width = PositiveScalar('The outer width (before rotation) in '
+                                 'pixels as a float.')
+    inner_height = PositiveScalar('The inner height (before rotation) in '
+                                  'pixels as a float.')
+    outer_height = PositiveScalar('The outer height (before rotation) in '
+                                  'pixels as a float.')
+    angle = ScalarAngle('The rotation angle measured anti-clockwise as a '
+                        '|Quantity| angle.')
+    meta = RegionMetaDescr('The meta attributes as a |RegionMeta|')
+    visual = RegionVisualDescr('The visual attributes as a |RegionVisual|.')
 
     def __init__(self, center, inner_width, outer_width, inner_height,
                  outer_height, angle=0 * u.deg, meta=None, visual=None):
@@ -241,6 +259,11 @@ class AsymmetricAnnulusPixelRegion(AnnulusPixelRegion):
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
 
+        if inner_width >= outer_width:
+            raise ValueError('outer_width must be greater than inner_width')
+        if inner_height >= outer_height:
+            raise ValueError('outer_height must be greater than inner_height')
+
     @property
     def _inner_region(self):
         return self._component_class(self.center, self.inner_width,
@@ -254,15 +277,18 @@ class AsymmetricAnnulusPixelRegion(AnnulusPixelRegion):
                                      self.meta, self.visual)
 
     def to_sky_args(self, wcs):
-        center = pixel_to_skycoord(self.center.x, self.center.y, wcs)
+        center = wcs.pixel_to_world(self.center.x, self.center.y)
         _, pixscale, north_angle = pixel_scale_angle_at_skycoord(center, wcs)
         inner_width = (self.inner_width * u.pix * pixscale).to(u.arcsec)
-        inner_height = (self.inner_height * u.pix * pixscale).to(u.arcsec)
         outer_width = (self.outer_width * u.pix * pixscale).to(u.arcsec)
+        inner_height = (self.inner_height * u.pix * pixscale).to(u.arcsec)
         outer_height = (self.outer_height * u.pix * pixscale).to(u.arcsec)
+        # region sky angles are defined relative to the WCS longitude axis;
+        # photutils aperture sky angles are defined as the PA of the
+        # semimajor axis (i.e., relative to the WCS latitude axis)
         angle = self.angle - (north_angle - 90 * u.deg)
 
-        return (center, inner_width, inner_height, outer_width, outer_height,
+        return (center, inner_width, outer_width, inner_height, outer_height,
                 angle)
 
 
@@ -278,32 +304,39 @@ class AsymmetricAnnulusSkyRegion(SkyRegion):
         The position of the center of the annulus.
     inner_width : `~astropy.units.Quantity`
         The inner width of the annulus (before rotation) as an angle.
-    inner_height : `~astropy.units.Quantity`
-        The inner height of the annulus (before rotation) as an angle.
     outer_width : `~astropy.units.Quantity`
         The outer width of the annulus (before rotation) as an angle.
+    inner_height : `~astropy.units.Quantity`
+        The inner height of the annulus (before rotation) as an angle.
     outer_height : `~astropy.units.Quantity`
         The outer height of the annulus (before rotation) as an angle.
     angle : `~astropy.units.Quantity`, optional
         The rotation angle of the annulus, measured anti-clockwise. If
         set to zero (the default), the width axis is lined up with the
         longitude axis of the celestial coordinates
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
     """
 
-    _params = ('center', 'inner_width', 'inner_height', 'outer_width',
+    _params = ('center', 'inner_width', 'outer_width', 'inner_height',
                'outer_height', 'angle')
 
-    center = ScalarSky('center')
-    inner_width = QuantityLength('inner_width')
-    outer_width = QuantityLength('outer_width')
-    inner_height = QuantityLength('inner_height')
-    outer_height = QuantityLength('outer_height')
-    angle = QuantityLength('angle')
+    center = ScalarSkyCoord('The center position as a |SkyCoord|.')
+    inner_width = PositiveScalarAngle('The inner width (before rotation) as '
+                                      'a |Quantity| angle.')
+    outer_width = PositiveScalarAngle('The outer width (before rotation) as '
+                                      'a |Quantity| angle.')
+    inner_height = PositiveScalarAngle('The inner height (before rotation) '
+                                       'as a |Quantity| angle.')
+    outer_height = PositiveScalarAngle('The outer height (before rotation) '
+                                       'as a |Quantity| angle.')
+    angle = ScalarAngle('The rotation angle measured anti-clockwise as a'
+                        '|Quantity| angle.')
+    meta = RegionMetaDescr('The meta attributes as a |RegionMeta|')
+    visual = RegionVisualDescr('The visual attributes as a |RegionVisual|.')
 
     def __init__(self, center, inner_width, outer_width, inner_height,
                  outer_height, angle=0 * u.deg, meta=None, visual=None):
@@ -316,17 +349,25 @@ class AsymmetricAnnulusSkyRegion(SkyRegion):
         self.meta = meta or RegionMeta()
         self.visual = visual or RegionVisual()
 
+        if inner_width >= outer_width:
+            raise ValueError('outer_width must be greater than inner_width')
+        if inner_height >= outer_height:
+            raise ValueError('outer_height must be greater than inner_height')
+
     def to_pixel_args(self, wcs):
         center, pixscale, north_angle = pixel_scale_angle_at_skycoord(
             self.center, wcs)
         center = PixCoord(center.x, center.y)
         inner_width = (self.inner_width / pixscale).to(u.pix).value
-        inner_height = (self.inner_height / pixscale).to(u.pix).value
         outer_width = (self.outer_width / pixscale).to(u.pix).value
+        inner_height = (self.inner_height / pixscale).to(u.pix).value
         outer_height = (self.outer_height / pixscale).to(u.pix).value
+        # region sky angles are defined relative to the WCS longitude axis;
+        # photutils aperture sky angles are defined as the PA of the
+        # semimajor axis (i.e., relative to the WCS latitude axis)
         angle = self.angle + (north_angle - 90 * u.deg)
 
-        return (center, inner_width, inner_height, outer_width, outer_height,
+        return (center, inner_width, outer_width, inner_height, outer_height,
                 angle)
 
 
@@ -341,12 +382,12 @@ class EllipseAnnulusPixelRegion(AsymmetricAnnulusPixelRegion):
     inner_width : float
         The inner width of the elliptical annulus (before rotation) in
         pixels.
-    inner_height : float
-        The inner height of the elliptical annulus (before rotation) in
-        pixels.
     outer_width : float
         The outer width of the elliptical annulus (before rotation) in
         pixels.
+    inner_height : float
+        The inner height of the elliptical annulus (before rotation) in
+        pixels.
     outer_height : float
         The outer height of the elliptical annulus (before rotation) in
         pixels.
@@ -354,10 +395,10 @@ class EllipseAnnulusPixelRegion(AsymmetricAnnulusPixelRegion):
         The rotation angle of the elliptical annulus, measured
         anti-clockwise. If set to zero (the default), the width axis is
         lined up with the x axis.
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
 
     Examples
@@ -369,33 +410,43 @@ class EllipseAnnulusPixelRegion(AsymmetricAnnulusPixelRegion):
         from regions import PixCoord, EllipseAnnulusPixelRegion
         import matplotlib.pyplot as plt
 
-        x, y = 6, 6
-        inner_width = 5.5
-        inner_height = 3.5
-        outer_width = 8.5
-        outer_height = 6.5
-        angle = Angle("45deg")
-
         fig, ax = plt.subplots(1, 1)
 
-        center = PixCoord(x=x, y=y)
-        reg = EllipseAnnulusPixelRegion(center=center, inner_width=inner_width,
-                                        inner_height=inner_height,
-                                        outer_width=outer_width,
-                                        outer_height=outer_height, angle=angle)
-        patch = reg.as_artist(facecolor='none', edgecolor='red', lw=2)
-        ax.add_patch(patch)
+        reg = EllipseAnnulusPixelRegion(PixCoord(6, 6),
+                                        inner_width=5.5,
+                                        outer_width=8.5,
+                                        inner_height=3.5,
+                                        outer_height=6.5,
+                                        angle=Angle('45deg'))
+        patch = reg.plot(ax=ax, facecolor='none', edgecolor='red', lw=2,
+                         label='Ellipse Annulus')
 
-        plt.xlim(-5, 20)
-        plt.ylim(-5, 20)
+        ax.legend(handles=(patch,), loc='upper center')
+        ax.set_xlim(-5, 20)
+        ax.set_ylim(-5, 20)
         ax.set_aspect('equal')
     """
 
+    # duplicated from AsymmetricAnnulusPixelRegion because otherwise Sphinx
+    # ignores the docstrings in the parent class
+    center = ScalarPixCoord('The center pixel position as a |PixCoord|.')
+    inner_width = PositiveScalar('The inner width (before rotation) in '
+                                 'pixels as a float.')
+    outer_width = PositiveScalar('The outer width (before rotation) in '
+                                 'pixels as a float.')
+    inner_height = PositiveScalar('The inner height (before rotation) in '
+                                  'pixels as a float.')
+    outer_height = PositiveScalar('The outer height (before rotation) in '
+                                  'pixels as a float.')
+    angle = ScalarAngle('The rotation angle measured anti-clockwise as a '
+                        '|Quantity| angle.')
+
     _component_class = EllipsePixelRegion
 
     def to_sky(self, wcs):
-        return EllipseAnnulusSkyRegion(
-            *self.to_sky_args(wcs), meta=self.meta, visual=self.visual)
+        return EllipseAnnulusSkyRegion(*self.to_sky_args(wcs),
+                                       meta=self.meta.copy(),
+                                       visual=self.visual.copy())
 
 
 class EllipseAnnulusSkyRegion(AsymmetricAnnulusSkyRegion):
@@ -409,12 +460,12 @@ class EllipseAnnulusSkyRegion(AsymmetricAnnulusSkyRegion):
     inner_width : `~astropy.units.Quantity`
         The inner width of the elliptical annulus (before rotation) as
         an angle.
-    inner_height : `~astropy.units.Quantity`
-        The inner height of the elliptical annulus (before rotation) as
-        an angle.
     outer_width : `~astropy.units.Quantity`
         The outer width of the elliptical annulus (before rotation) as
         an angle.
+    inner_height : `~astropy.units.Quantity`
+        The inner height of the elliptical annulus (before rotation) as
+        an angle.
     outer_height : `~astropy.units.Quantity`
         The outer height of the elliptical annulus (before rotation) as
         an angle.
@@ -422,18 +473,33 @@ class EllipseAnnulusSkyRegion(AsymmetricAnnulusSkyRegion):
         The rotation angle of the elliptical annulus, measured
         anti-clockwise. If set to zero (the default), the width axis is
         lined up with the longitude axis of the celestial coordinates
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
     """
 
+    # duplicated from AsymmetricAnnulusSkyRegion because otherwise Sphinx
+    # ignores the docstrings in the parent class
+    center = ScalarSkyCoord('The center position as a |SkyCoord|.')
+    inner_width = PositiveScalarAngle('The inner width (before rotation) as '
+                                      'a |Quantity| angle.')
+    outer_width = PositiveScalarAngle('The outer width (before rotation) as '
+                                      'a |Quantity| angle.')
+    inner_height = PositiveScalarAngle('The inner height (before rotation) '
+                                       'as a |Quantity| angle.')
+    outer_height = PositiveScalarAngle('The outer height (before rotation) '
+                                       'as a |Quantity| angle.')
+    angle = ScalarAngle('The rotation angle measured anti-clockwise as a '
+                        '|Quantity| angle.')
+
     _component_class = EllipseSkyRegion
 
     def to_pixel(self, wcs):
-        return EllipseAnnulusPixelRegion(
-            *self.to_pixel_args(wcs), meta=self.meta, visual=self.visual)
+        return EllipseAnnulusPixelRegion(*self.to_pixel_args(wcs),
+                                         meta=self.meta.copy(),
+                                         visual=self.visual.copy())
 
 
 class RectangleAnnulusPixelRegion(AsymmetricAnnulusPixelRegion):
@@ -447,12 +513,12 @@ class RectangleAnnulusPixelRegion(AsymmetricAnnulusPixelRegion):
     inner_width : float
         The inner width of the rectangular annulus (before rotation) in
         pixels.
-    inner_height : float
-        The inner height of the rectangular annulus (before rotation) in
-        pixels.
     outer_width : float
         The outer width of the rectangular annulus (before rotation) in
         pixels.
+    inner_height : float
+        The inner height of the rectangular annulus (before rotation) in
+        pixels.
     outer_height : float
         The outer height of the rectangular annulus (before rotation) in
         pixels.
@@ -460,10 +526,10 @@ class RectangleAnnulusPixelRegion(AsymmetricAnnulusPixelRegion):
         The rotation angle of the rectangular annulus, measured
         anti-clockwise. If set to zero (the default), the width axis is
         lined up with the x axis.
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
 
     Examples
@@ -475,35 +541,43 @@ class RectangleAnnulusPixelRegion(AsymmetricAnnulusPixelRegion):
         from regions import PixCoord, RectangleAnnulusPixelRegion
         import matplotlib.pyplot as plt
 
-        x, y = 6, 6
-        inner_width = 5.5
-        inner_height = 3.5
-        outer_width = 8.5
-        outer_height = 6.5
-        angle = Angle("45deg")
-
         fig, ax = plt.subplots(1, 1)
 
-        center = PixCoord(x=x, y=y)
-        reg = RectangleAnnulusPixelRegion(center=center,
-                                          inner_width=inner_width,
-                                          inner_height=inner_height,
-                                          outer_width=outer_width,
-                                          outer_height=outer_height,
-                                          angle=angle)
-        patch = reg.as_artist(facecolor='none', edgecolor='red', lw=2)
-        ax.add_patch(patch)
+        reg = RectangleAnnulusPixelRegion(PixCoord(x=6, y=6),
+                                          inner_width=5.5,
+                                          outer_width=8.5,
+                                          inner_height=3.5,
+                                          outer_height=6.5,
+                                          angle=Angle('45deg'))
+        patch = reg.plot(ax=ax, facecolor='none', edgecolor='red', lw=2,
+                         label='Rectangle Annulus')
 
-        plt.xlim(-5, 20)
-        plt.ylim(-5, 20)
+        ax.legend(handles=(patch,), loc='upper center')
+        ax.set_xlim(-5, 20)
+        ax.set_ylim(-5, 20)
         ax.set_aspect('equal')
     """
 
+    # duplicated from AsymmetricAnnulusPixelRegion because otherwise Sphinx
+    # ignores the docstrings in the parent class
+    center = ScalarPixCoord('The center pixel position as a |PixCoord|.')
+    inner_width = PositiveScalar('The inner width (before rotation) in '
+                                 'pixels as a float.')
+    outer_width = PositiveScalar('The outer width (before rotation) in '
+                                 'pixels as a float.')
+    inner_height = PositiveScalar('The inner height (before rotation) in '
+                                  'pixels as a float.')
+    outer_height = PositiveScalar('The outer height (before rotation) in '
+                                  'pixels as a float.')
+    angle = ScalarAngle('The rotation angle measured anti-clockwise as a '
+                        '|Quantity| angle.')
+
     _component_class = RectanglePixelRegion
 
     def to_sky(self, wcs):
-        return RectangleAnnulusSkyRegion(
-            *self.to_sky_args(wcs), meta=self.meta, visual=self.visual)
+        return RectangleAnnulusSkyRegion(*self.to_sky_args(wcs),
+                                         meta=self.meta.copy(),
+                                         visual=self.visual.copy())
 
 
 class RectangleAnnulusSkyRegion(AsymmetricAnnulusSkyRegion):
@@ -518,12 +592,12 @@ class RectangleAnnulusSkyRegion(AsymmetricAnnulusSkyRegion):
     inner_width : `~astropy.units.Quantity`
         The inner width of the rectangular annulus (before rotation) as
         an angle.
-    inner_height : `~astropy.units.Quantity`
-        The inner height of the rectangular annulus (before rotation) as
-        an angle.
     outer_width : `~astropy.units.Quantity`
         The outer width of the rectangular annulus (before rotation) as
         an angle.
+    inner_height : `~astropy.units.Quantity`
+        The inner height of the rectangular annulus (before rotation) as
+        an angle.
     outer_height : `~astropy.units.Quantity`
         The outer height of the rectangular annulus (before rotation) as
         an angle.
@@ -531,15 +605,30 @@ class RectangleAnnulusSkyRegion(AsymmetricAnnulusSkyRegion):
         The rotation angle of the rectangular annulus, measured
         anti-clockwise. If set to zero (the default), the width axis is
         lined up with the longitude axis of the celestial coordinates
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
     """
 
+    # duplicated from AsymmetricAnnulusSkyRegion because otherwise Sphinx
+    # ignores the docstrings in the parent class
+    center = ScalarSkyCoord('The center position as a |SkyCoord|.')
+    inner_width = PositiveScalarAngle('The inner width (before rotation) as '
+                                      'a |Quantity| angle.')
+    outer_width = PositiveScalarAngle('The outer width (before rotation) as '
+                                      'a |Quantity| angle.')
+    inner_height = PositiveScalarAngle('The inner height (before rotation) '
+                                       'as a |Quantity| angle.')
+    outer_height = PositiveScalarAngle('The outer height (before rotation) '
+                                       'as a |Quantity| angle.')
+    angle = ScalarAngle('The rotation angle measured anti-clockwise as a '
+                        '|Quantity| angle.')
+
     _component_class = RectangleSkyRegion
 
     def to_pixel(self, wcs):
-        return RectangleAnnulusPixelRegion(
-            *self.to_pixel_args(wcs), meta=self.meta, visual=self.visual)
+        return RectangleAnnulusPixelRegion(*self.to_pixel_args(wcs),
+                                           meta=self.meta.copy(),
+                                           visual=self.visual.copy())
