@@ -7,12 +7,12 @@ import math
 
 from astropy.coordinates import Angle
 import astropy.units as u
-from astropy.wcs.utils import pixel_to_skycoord
 import numpy as np
 
 from ..core.attributes import (ScalarPixCoord, PositiveScalar,
                                PositiveScalarAngle, ScalarAngle,
-                               ScalarSkyCoord)
+                               ScalarSkyCoord, RegionMetaDescr,
+                               RegionVisualDescr)
 from ..core.bounding_box import RegionBoundingBox
 from ..core.core import PixelRegion, SkyRegion
 from ..core.mask import RegionMask
@@ -40,10 +40,10 @@ class EllipsePixelRegion(PixelRegion):
         The rotation angle of the ellipse, measured anti-clockwise. If
         set to zero (the default), the width axis is lined up with the x
         axis.
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
 
     Examples
@@ -51,8 +51,6 @@ class EllipsePixelRegion(PixelRegion):
     .. plot::
         :include-source:
 
-        import numpy as np
-        from astropy.modeling.models import Ellipse2D
         from astropy.coordinates import Angle
         from regions import PixCoord, EllipsePixelRegion
         import matplotlib.pyplot as plt
@@ -79,6 +77,8 @@ class EllipsePixelRegion(PixelRegion):
                             'pixels as a float.')
     angle = ScalarAngle('The rotation angle measured anti-clockwise as a '
                         '|Quantity| angle.')
+    meta = RegionMetaDescr('The meta attributes as a |RegionMeta|')
+    visual = RegionVisualDescr('The visual attributes as a |RegionVisual|.')
 
     def __init__(self, center, width, height, angle=0. * u.deg, meta=None,
                  visual=None):
@@ -108,8 +108,7 @@ class EllipsePixelRegion(PixelRegion):
             return np.logical_not(in_ell)
 
     def to_sky(self, wcs):
-        # TODO: write a pixel_to_skycoord_scale_angle
-        center = pixel_to_skycoord(self.center.x, self.center.y, wcs)
+        center = wcs.pixel_to_world(self.center.x, self.center.y)
         _, pixscale, north_angle = pixel_scale_angle_at_skycoord(center, wcs)
         height = Angle(self.height * u.pix * pixscale, 'arcsec')
         width = Angle(self.width * u.pix * pixscale, 'arcsec')
@@ -179,7 +178,7 @@ class EllipsePixelRegion(PixelRegion):
 
     def as_artist(self, origin=(0, 0), **kwargs):
         """
-        Return a matplotlib patch object for this region
+        Return a matplotlib patch object for the region
         (`matplotlib.patches.Ellipse`).
 
         Parameters
@@ -343,10 +342,10 @@ class EllipseSkyRegion(SkyRegion):
         The rotation angle of the ellipse, measured anti-clockwise. If
         set to zero (the default), the width axis is lined up with the
         longitude axis of the celestial coordinates.
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
     """
 
@@ -358,6 +357,8 @@ class EllipseSkyRegion(SkyRegion):
                                  'as a |Quantity| angle.')
     angle = ScalarAngle('The rotation angle measured anti-clockwise as a '
                         '|Quantity| angle.')
+    meta = RegionMetaDescr('The meta attributes as a |RegionMeta|')
+    visual = RegionVisualDescr('The visual attributes as a |RegionVisual|.')
 
     def __init__(self, center, width, height, angle=0. * u.deg, meta=None,
                  visual=None):
