@@ -3,10 +3,10 @@
 This module defines line regions in both pixel and sky coordinates.
 """
 
-from astropy.wcs.utils import pixel_to_skycoord, skycoord_to_pixel
 import numpy as np
 
-from ..core.attributes import ScalarPixCoord, ScalarSkyCoord
+from ..core.attributes import (ScalarPixCoord, ScalarSkyCoord,
+                               RegionMetaDescr, RegionVisualDescr)
 from ..core.bounding_box import RegionBoundingBox
 from ..core.core import PixelRegion, SkyRegion
 from ..core.metadata import RegionMeta, RegionVisual
@@ -25,10 +25,10 @@ class LinePixelRegion(PixelRegion):
         The start position.
     end : `~regions.PixCoord`
         The end position.
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
 
     Examples
@@ -56,6 +56,8 @@ class LinePixelRegion(PixelRegion):
     _mpl_artist = 'Patch'
     start = ScalarPixCoord('The start pixel position as a |PixCoord|.')
     end = ScalarPixCoord('The end pixel position as a |PixCoord|.')
+    meta = RegionMetaDescr('The meta attributes as a |RegionMeta|')
+    visual = RegionVisualDescr('The visual attributes as a |RegionVisual|.')
 
     def __init__(self, start, end, meta=None, visual=None):
         self.start = start
@@ -79,8 +81,8 @@ class LinePixelRegion(PixelRegion):
             return np.logical_not(in_reg)
 
     def to_sky(self, wcs):
-        start = pixel_to_skycoord(self.start.x, self.start.y, wcs)
-        end = pixel_to_skycoord(self.end.x, self.end.y, wcs)
+        start = wcs.pixel_to_world(self.start.x, self.start.y)
+        end = wcs.pixel_to_world(self.end.x, self.end.y)
         return LineSkyRegion(start, end, meta=self.meta.copy(),
                              visual=self.visual.copy())
 
@@ -167,16 +169,18 @@ class LineSkyRegion(SkyRegion):
         The start position.
     end : `~astropy.coordinates.SkyCoord`
         The end position.
-    meta : `~regions.RegionMeta`, optional
-        A dictionary that stores the meta attributes of this region.
-    visual : `~regions.RegionVisual`, optional
-        A dictionary that stores the visual meta attributes of this
+    meta : `~regions.RegionMeta` or `dict`, optional
+        A dictionary that stores the meta attributes of the region.
+    visual : `~regions.RegionVisual` or `dict`, optional
+        A dictionary that stores the visual meta attributes of the
         region.
     """
 
     _params = ('start', 'end')
     start = ScalarSkyCoord('The start position as a |SkyCoord|.')
     end = ScalarSkyCoord('The end position as a |SkyCoord|.')
+    meta = RegionMetaDescr('The meta attributes as a |RegionMeta|')
+    visual = RegionVisualDescr('The visual attributes as a |RegionVisual|.')
 
     def __init__(self, start, end, meta=None, visual=None):
         self.start = start
@@ -192,9 +196,9 @@ class LineSkyRegion(SkyRegion):
             return True
 
     def to_pixel(self, wcs):
-        start_x, start_y = skycoord_to_pixel(self.start, wcs=wcs)
+        start_x, start_y = wcs.world_to_pixel(self.start)
         start = PixCoord(start_x, start_y)
-        end_x, end_y = skycoord_to_pixel(self.end, wcs=wcs)
+        end_x, end_y = wcs.world_to_pixel(self.end)
         end = PixCoord(end_x, end_y)
         return LinePixelRegion(start, end, meta=self.meta.copy(),
                                visual=self.visual.copy())
