@@ -3,6 +3,7 @@
 The tests in this file simply check what functionality is currently
 implemented and doesn't check anything about correctness.
 """
+from collections import OrderedDict
 import itertools
 
 from astropy.coordinates import SkyCoord
@@ -12,6 +13,7 @@ import pytest
 
 from ...core.core import PixelRegion, Region, SkyRegion
 from ...core.mask import RegionMask
+from ...core.metadata import RegionMeta, RegionVisual
 from ...core.pixcoord import PixCoord
 from ..annulus import (CircleAnnulusPixelRegion, CircleAnnulusSkyRegion,
                        EllipseAnnulusPixelRegion, EllipseAnnulusSkyRegion,
@@ -115,13 +117,15 @@ def test_sky_to_pix(region):
 @pytest.mark.parametrize('region', PIXEL_REGIONS, ids=ids_func)
 def test_attribute_validation_pixel_regions(region):
     invalid_values = dict(center=[PixCoord([1, 2], [2, 3]), 1,
-                                  SkyCoord(1 * u.deg, 2 * u.deg)],
-                          radius=[u.Quantity("1deg"), [1], PixCoord(1, 2)],
+                                  SkyCoord(1 * u.deg, 2 * u.deg),
+                                  (10, 10), (10 * u.deg, 10 * u.deg)],
+                          radius=[u.Quantity("1deg"), [1], PixCoord(1, 2),
+                                  3 * u.km, 0.0, -10.],
                           angle=[u.Quantity([1 * u.deg, 2 * u.deg]), 2,
-                                 PixCoord(1, 2)],
+                                 PixCoord(1, 2), 3 * u.km],
                           vertices=[u.Quantity("1"), 2, PixCoord(1, 2),
-                                    PixCoord([[1, 2]], [[2, 3]])]
-                          )
+                                    PixCoord([[1, 2]], [[2, 3]]), 3 * u.km,
+                                    (10, 10), (10 * u.deg, 10 * u.deg)])
     invalid_values['width'] = invalid_values['radius']
     invalid_values['height'] = invalid_values['radius']
     invalid_values['inner_height'] = invalid_values['radius']
@@ -138,21 +142,25 @@ def test_attribute_validation_pixel_regions(region):
             for val in invalid_values.get(attr, None):
                 with pytest.raises(ValueError) as excinfo:
                     setattr(region, attr, val)
-                assert f'The {attr} must be' in str(excinfo.value)
+                assert f'{attr!r} must' in str(excinfo.value)
 
 
 @pytest.mark.parametrize('region', SKY_REGIONS, ids=ids_func)
 def test_attribute_validation_sky_regions(region):
     invalid_values = dict(center=[PixCoord([1, 2], [2, 3]), 1,
-                                  SkyCoord([1 * u.deg], [2 * u.deg])],
+                                  SkyCoord([1 * u.deg], [2 * u.deg]),
+                                  (10, 10), (10 * u.deg, 10 * u.deg)],
                           radius=[u.Quantity([1 * u.deg, 5 * u.deg]),
-                                  [1], SkyCoord(1 * u.deg, 2 * u.deg), 1],
+                                  [1], SkyCoord(1 * u.deg, 2 * u.deg),
+                                  1, 3 * u.km, 0.0 * u.deg, -10. * u.deg],
                           angle=[u.Quantity([1 * u.deg, 2 * u.deg]), 2,
-                                 SkyCoord(1 * u.deg, 2 * u.deg)],
+                                 SkyCoord(1 * u.deg, 2 * u.deg), 3. * u.km],
                           vertices=[u.Quantity("1deg"), 2,
                                     SkyCoord(1 * u.deg, 2 * u.deg),
                                     SkyCoord([[1 * u.deg, 2 * u.deg]],
-                                             [[2 * u.deg, 3 * u.deg]])])
+                                             [[2 * u.deg, 3 * u.deg]]),
+                                    3 * u.km, (10, 10),
+                                    (10 * u.deg, 10 * u.deg)])
 
     invalid_values['width'] = invalid_values['radius']
     invalid_values['height'] = invalid_values['radius']
@@ -170,4 +178,23 @@ def test_attribute_validation_sky_regions(region):
             for val in invalid_values.get(attr, None):
                 with pytest.raises(ValueError) as excinfo:
                     setattr(region, attr, val)
-                assert f'The {attr} must be' in str(excinfo.value)
+                assert f'{attr!r} must' in str(excinfo.value)
+
+
+@pytest.mark.parametrize('region', PIXEL_REGIONS + SKY_REGIONS, ids=ids_func)
+def test_metadata(region):
+    region.meta = {'text': 'hello'}
+    region.visual = {'color': 'blue'}
+    assert isinstance(region.meta, RegionMeta)
+    assert isinstance(region.visual, RegionVisual)
+
+    # dict subclasses are allowed
+    region.meta = OrderedDict({'text': 'hello'})
+    region.visual = OrderedDict({'color': 'blue'})
+    assert isinstance(region.meta, RegionMeta)
+    assert isinstance(region.visual, RegionVisual)
+
+    with pytest.raises(ValueError):
+        region.meta = 1
+    with pytest.raises(ValueError):
+        region.visual = 'blue'
