@@ -10,11 +10,11 @@ import numpy as np
 from numpy.testing import assert_allclose
 import pytest
 
-from ...core import PixCoord
+from ...core import PixCoord, RegionMeta, RegionVisual
 from ...tests.helpers import make_simple_wcs
+from ..._utils.optional_deps import HAS_MATPLOTLIB  # noqa
 from ..circle import CirclePixelRegion, CircleSkyRegion
 from .test_common import BaseTestPixelRegion, BaseTestSkyRegion
-from .utils import HAS_MATPLOTLIB  # noqa
 
 
 @pytest.fixture(scope='session', name='wcs')
@@ -25,7 +25,9 @@ def wcs_fixture():
 
 
 class TestCirclePixelRegion(BaseTestPixelRegion):
-    reg = CirclePixelRegion(PixCoord(3, 4), radius=2)
+    meta = RegionMeta({'text': 'test'})
+    visual = RegionVisual({'color': 'blue'})
+    reg = CirclePixelRegion(PixCoord(3, 4), radius=2, meta=meta, visual=visual)
     sample_box = [0, 6, 1, 7]
     inside = [(3, 4)]
     outside = [(3, 0)]
@@ -38,8 +40,8 @@ class TestCirclePixelRegion(BaseTestPixelRegion):
         reg = self.reg.copy()
         assert reg.center.xy == (3, 4)
         assert reg.radius == 2
-        assert reg.visual == {}
-        assert reg.meta == {}
+        assert reg.meta == self.meta
+        assert reg.visual == self.visual
 
     def test_pix_sky_roundtrip(self):
         wcs = make_simple_wcs(SkyCoord(2 * u.deg, 3 * u.deg), 0.1 * u.deg, 20)
@@ -47,6 +49,14 @@ class TestCirclePixelRegion(BaseTestPixelRegion):
         assert_allclose(reg_new.center.x, self.reg.center.x)
         assert_allclose(reg_new.center.y, self.reg.center.y)
         assert_allclose(reg_new.radius, self.reg.radius)
+        assert reg_new.meta == self.reg.meta
+        assert reg_new.visual == self.reg.visual
+
+        # test that converted region meta and visual are copies and not views
+        reg_new.meta['text'] = 'new'
+        reg_new.visual['color'] = 'green'
+        assert reg_new.meta['text'] != self.reg.meta['text']
+        assert reg_new.visual['color'] != self.reg.visual['color']
 
     @pytest.mark.skipif('not HAS_MATPLOTLIB')
     def test_as_artist(self):
@@ -58,9 +68,22 @@ class TestCirclePixelRegion(BaseTestPixelRegion):
         reg = self.reg.rotate(PixCoord(2, 3), 90 * u.deg)
         assert_allclose(reg.center.xy, (1, 4))
 
+    def test_eq(self):
+        reg = self.reg.copy()
+        assert reg == self.reg
+        reg.radius = 3
+        assert reg != self.reg
+
+    def test_zero_size(self):
+        with pytest.raises(ValueError):
+            CirclePixelRegion(PixCoord(50, 50), radius=0)
+
 
 class TestCircleSkyRegion(BaseTestSkyRegion):
-    reg = CircleSkyRegion(SkyCoord(3 * u.deg, 4 * u.deg), 2 * u.arcsec)
+    meta = RegionMeta({'text': 'test'})
+    visual = RegionVisual({'color': 'blue'})
+    reg = CircleSkyRegion(SkyCoord(3 * u.deg, 4 * u.deg), 2 * u.arcsec,
+                          meta=meta, visual=visual)
 
     expected_repr = ('<CircleSkyRegion(center=<SkyCoord (ICRS): (ra, dec) in '
                      'deg\n    (3., 4.)>, radius=2.0 arcsec)>')
@@ -72,8 +95,8 @@ class TestCircleSkyRegion(BaseTestSkyRegion):
         reg = self.reg.copy()
         assert_allclose(reg.center.ra.deg, 3)
         assert_allclose(reg.radius.to_value("arcsec"), 2)
-        assert reg.visual == {}
-        assert reg.meta == {}
+        assert reg.meta == self.meta
+        assert reg.visual == self.visual
 
     def test_transformation(self, wcs):
         skycoord = SkyCoord(3 * u.deg, 4 * u.deg, frame='galactic')
@@ -98,7 +121,7 @@ class TestCircleSkyRegion(BaseTestSkyRegion):
         radius = 2 * u.arcsec
         with pytest.raises(ValueError) as excinfo:
             CircleSkyRegion(center, radius)
-        estr = 'The center must be a scalar SkyCoord object'
+        estr = "'center' must be a scalar SkyCoord"
         assert estr in str(excinfo.value)
 
     def test_contains(self, wcs):
@@ -106,3 +129,13 @@ class TestCircleSkyRegion(BaseTestSkyRegion):
         # 1,2 is outside, 3,4 is the center and is inside
         assert all(self.reg.contains(position, wcs)
                    == np.array([False, True], dtype='bool'))
+
+    def test_eq(self):
+        reg = self.reg.copy()
+        assert reg == self.reg
+        reg.radius = 3 * u.arcsec
+        assert reg != self.reg
+
+    def test_zero_size(self):
+        with pytest.raises(ValueError):
+            CircleSkyRegion(SkyCoord(3 * u.deg, 4 * u.deg), 0. * u.arcsec)
